@@ -18,21 +18,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import absolute_import
 from django.conf import settings
 from horizon import exceptions
 import logging
 from openstack_dashboard.api import base
-import six
 
 from manilaclient import client as manila_client
 
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-# NOTE(vponomaryov): update version to 2.34 when manilaclient is released with
-# its support. It will allow to show 'availability zones' for share groups.
-MANILA_VERSION = "2.32"  # requires manilaclient 1.13.0 or newer
+MANILA_VERSION = "2.38"
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -116,8 +112,8 @@ def share_delete(request, share_id, share_group_id=None):
 
 def share_update(request, share_id, name, description, is_public=''):
     share_data = {'display_name': name, 'display_description': description}
-    if not isinstance(is_public, six.string_types):
-        is_public = six.text_type(is_public)
+    if not isinstance(is_public, str):
+        is_public = str(is_public)
     if is_public and is_public.lower() != 'none':
         share_data['is_public'] = is_public
     return manilaclient(request).shares.update(share_id, **share_data)
@@ -397,11 +393,10 @@ def share_type_get(request, share_type_id):
 
 
 def share_type_create(request, name, spec_driver_handles_share_servers,
-                      spec_snapshot_support=True, is_public=True):
+                      is_public=True):
     return manilaclient(request).share_types.create(
         name=name,
         spec_driver_handles_share_servers=spec_driver_handles_share_servers,
-        spec_snapshot_support=spec_snapshot_support,
         is_public=is_public)
 
 
@@ -644,3 +639,18 @@ def share_group_type_unset_specs(request, share_group_type, keys):
 def share_group_type_get_specs(request, share_group_type):
     return manilaclient(request).share_group_types.get(
         share_group_type).get_keys()
+
+
+# ####### User Messages # ########
+def messages_get(request, message_id):
+    return manilaclient(request).messages.get(message_id)
+
+
+def messages_list(request, search_opts=None, sort_key=None, sort_dir=None):
+    return manilaclient(request).messages.list(search_opts=search_opts,
+                                               sort_key=sort_key,
+                                               sort_dir=sort_dir)
+
+
+def messages_delete(request, message_id):
+    return manilaclient(request).messages.delete(message_id)
