@@ -1,3 +1,5 @@
+# Copyright 2017 Mirantis, Inc.
+#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -11,15 +13,16 @@
 # under the License.
 
 from django.utils.translation import ugettext_lazy as _
-
 import horizon
-
 from openstack_dashboard.dashboards.admin import dashboard
 
 
 class Shares(horizon.Panel):
     name = _("Shares")
     slug = "shares"
-    permissions = ('openstack.services.share',)
+    permissions = (
+        'openstack.services.share',
+    )
+
 
 dashboard.Admin.register(Shares)
